@@ -1,7 +1,6 @@
 import os
 import site
 import cv2
-import subprocess
 import base64
 import numpy as np
 from tqdm import tqdm
@@ -9,16 +8,77 @@ from datetime import datetime
 from stable_baselines3.common.vec_env import VecVideoRecorder, DummyVecEnv
 from pathlib import Path
 from IPython import display as ipythondisplay
+import subprocess
+import sys
+
+
+def run_command(cmd: str, stderr=subprocess.STDOUT) -> None:
+    """Run a command in terminal
+
+    Copied from: https://stackoverflow.com/questions/64920923/print-realtime-output-of-subprocess-in-jupyter-notebook
+
+    Args:
+        cmd (str): command to run in terminal
+        stderr (subprocess, optional): Where the error has to go. Defaults to subprocess.STDOUT.
+
+    Raises:
+        e: Excetion of the CalledProcessError
+    """
+    out = None
+    try:
+        out = subprocess.check_output(
+            [cmd],
+            shell=True,
+            stderr=stderr,
+            universal_newlines=True,
+        )
+    except subprocess.CalledProcessError as e:
+        print(f"ERROR {e.returncode}: {cmd}\n\t{e.output}", flush=True, file=sys.stderr)
+        raise e
+    print(out)
 
 
 def setup_notebook():
     if "google.colab" in str(get_ipython()):  # noqa:
         print("Running on CoLab.")
+
         # Required to source ros in new processes
         os.environ["EAGERX_COLAB"] = "1"
+
+        # Reload pil
+        import importlib
+        import PIL
+
+        importlib.reload(PIL.TiffTags)
+
+        try:
+            import eagerx_gui
+        except ImportError:
+            # Setup virtual display
+            command = "echo 'Setting up virtual display for visualisation' && apt-get install ffmpeg freeglut3-dev xvfb >> /tmp/eagerx_xvfb.txt 2>&1"
+            run_command(command)
+            os.system("Xvfb :1 -screen 0 1024x768x24 &")
+            os.environ["DISPLAY"] = ":1"
+
+            # Install eagerx-gui and deps
+            command = (
+                "echo 'Installing eagerx-gui dependencies' && pip install pyqt5 pyqtgraph >> /tmp/eagerx_gui_deps.txt 2>&1"
+            )
+            run_command(command)
+
+            command = "echo 'Installing eagerx-gui' && pip install --ignore-requires-python --no-deps eagerx-gui >> /tmp/eagerx_gui.txt 2>&1"
+            run_command(command)
+
+            # Install opencv headless
+            command = "echo 'Installing opencv-python-headless' && pip uninstall -y opencv-python opencv-python-headless >> /tmp/opencv_uninstall.txt 2>&1 && pip install opencv-python-headless >> /tmp/opencv_uninstall.txt"
+            run_command(command)
     else:
         print("Not running on CoLab.")
-
+        try:
+            import eagerx_gui
+        except ImportError:
+            command = "echo 'Installing eagerx-gui' && pip install eagerx-gui >> /tmp/eagerx_gui.txt 2>&1"
+            run_command(command)
     os.environ["EAGERX_RELOAD"] = "1"
 
 
@@ -117,6 +177,23 @@ def show_video(video_file, video_folder="videos/"):
     ipythondisplay.display(ipythondisplay.HTML(data="<br>".join(html)))
 
 
+def show_svg(svg_file: str, width: str = "100%"):
+    """Show SVG image in Jupyter notebook with custom size.
+
+    Adapted from https://stackoverflow.com/questions/51452569/how-to-resize-rescale-a-svg-graphic-in-an-ipython-jupyter-notebook
+    (Comment from Jay M)
+
+    :param svg_file: Path or filename.
+    :param width: Width of the svg.
+    :return: HTML of SVG
+    """
+    svg_file = svg_file if svg_file.lower().endswith(".svg") else svg_file + ".svg"
+    svg = str.encode(ipythondisplay.SVG(svg_file).data)
+    b64 = base64.b64encode(svg).decode("utf=8")
+    text = f'<img width="{width}" src="data:image/svg+xml;base64,{b64}" >'
+    return ipythondisplay.HTML(text)
+
+
 def evaluate(model, env, n_eval_episodes=3, episode_length=100, video_rate=None, video_prefix=""):
     video_folder = "videos/"
     # Create output folder if needed
