@@ -1,9 +1,8 @@
 from typing import Optional
-
-# IMPORT ROS
-from std_msgs.msg import Float32MultiArray, Float32
+import numpy as np
 
 # IMPORT EAGERX
+from eagerx.core.space import Space
 from eagerx.core.constants import process
 from eagerx.utils.utils import Msg
 from eagerx.core.entities import EngineNode
@@ -11,10 +10,9 @@ import eagerx.core.register as register
 
 
 class FloatOutput(EngineNode):
-    @staticmethod
-    @register.spec("FloatOutput", EngineNode)
-    def spec(
-        spec,
+    @classmethod
+    def make(
+        cls,
         name: str,
         rate: float,
         idx: Optional[int] = 0,
@@ -26,6 +24,8 @@ class FloatOutput(EngineNode):
 
         :param idx: index of the value of interest from the array.
         """
+        spec = cls.get_specification()
+
         # Modify default node params
         spec.config.name = name
         spec.config.rate = rate
@@ -35,17 +35,18 @@ class FloatOutput(EngineNode):
 
         # Custom node params
         spec.config.idx = idx
+        return spec
 
-    def initialize(self, idx):
-        self.obj_name = self.config["name"]
-        self.idx = idx
+    def initialize(self, spec, object_spec, simulator):
+        self.obj_name = object_spec.config.name
+        self.idx = spec.config.idx
 
     @register.states()
     def reset(self):
         pass
 
-    @register.inputs(observation_array=Float32MultiArray)
-    @register.outputs(observation=Float32)
+    @register.inputs(observation_array=Space(dtype="float32"))
+    @register.outputs(observation=Space(dtype="float32"))
     def callback(self, t_n: float, observation_array: Optional[Msg] = None):
-        data = observation_array.msgs[-1].data[self.idx]
-        return dict(observation=Float32(data=data))
+        data = observation_array.msgs[-1].data
+        return dict(observation=np.array(data[self.idx], dtype="float32"))
